==> distfun-0.3-1-src.zip: distfun/src/cdflib/ipmpar.c <==
/* ipmpar.f -- translated by f2c (version 20100827).
You must link the resulting object file with libf2c:
on Microsoft Windows system, link with libf2c.lib;
on Linux or Unix systems, link with .../path/to/libf2c.a -lm
or, if you install libf2c.a in a standard place, with -lf2c -lm
-- in that order, at the end of the command line, as in
cc *.o -lf2c -lm
Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

http://www.netlib.org/f2c/libf2c.zip
*/

#include "cdflib.h"

int ipmpar_(int *i__)
{
	/* System generated locals */
	int ret_val;

	/* Local variables */
	static int io;
	static float wte;

	/* ----------------------------------------------------------------------- */
	/*  intS. */

	/*     ASSUME intS ARE REPRESENTED IN THE N-DIGIT, BASE-A FORM */

	/*               SIGN ( X(N-1)*A**(N-1) + ... + X(1)*A + X(0) ) */

	/*               WHERE 0 .LE. X(I) .LT. A FOR I=0,...,N-1. */

	/*     IPMPAR(1) = A, THE BASE. */
	/*     IPMPAR(2) = N, THE NUMBER OF BASE-A DIGITS. */
	/*     IPMPAR(3) = A**N - 1, THE LARGEST MAGNITUDE. */

	/*  FLOATING-POINT NUMBERS. */

	/*     IT IS ASSUMED THAT THE SINGLE AND DOUBLE PRECISION FLOATING */
	/*     POINT ARITHMETICS HAVE THE SAME BASE, SAY B, AND THAT THE */
	/*     NONZERO NUMBERS ARE REPRESENTED IN THE FORM */

	/*               SIGN (B**E) * (X(1)/B + ... + X(M)/B**M) */

	/*               WHERE X(I) = 0,1,...,B-1 FOR I=1,...,M, */
	/*               X(1) .GE. 1, AND EMIN .LE. E .LE. EMAX. */

	/*     IPMPAR(4) = B, THE BASE. */
	/*  SINGLE-PRECISION */
	/*     IPMPAR(5) = M, THE NUMBER OF BASE-B DIGITS. */
	/*     IPMPAR(6) = EMIN, THE SMALLEST EXPONENT E. */
	/*     IPMPAR(7) = EMAX, THE LARGEST EXPONENT E. */
	/*  DOUBLE-PRECISION */
	/*     IPMPAR(8) = M, THE NUMBER OF BASE-B DIGITS. */
	/*     IPMPAR(9) = EMIN, THE SMALLEST EXPONENT E. */
	/*     IPMPAR(10) = EMAX, THE LARGEST EXPONENT E. */
	/* ----------------------------------------------------------------------- */
	/*     RWRITTEN BY JPC to use lapack dlamch + a small c program */
	/*     for ipmpar(3) */
	/* ----------------------------------------------------------------------- */
	/*      include 'stack.h' */
	switch (*i__) {
	case 1:  goto L1;
	case 2:  goto L1;
	case 3:  goto L3;
	case 4:  goto L4;
	case 5:  goto L1;
	case 6:  goto L1;
	case 7:  goto L1;
	case 8:  goto L1;
	case 9:  goto L9;
	case 10:  goto L10;
	}
L1:
	basout_(&io, &wte, "ipmpar called with wrong argument", (long int)33);
	ret_val = 0;
	return ret_val;
L3:
	ret_val = largestint_();
	return ret_val;
L4:
	ret_val = (int) dlamch_("b", (long int)1);
	return ret_val;
L9:
	ret_val = (int) dlamch_("m", (long int)1);
	return ret_val;
L10:
	ret_val = (int) dlamch_("l", (long int)1);
	return ret_val;
} /* ipmpar_ */

==> distfun-0.5-1-src.zip: distfun/src/cdflib/ipmpar.c <==
/* ipmpar.f -- translated by f2c (version 20100827).
with manual tuning by Michael Baudin (2012)
*/

#include "cdflib.h"
#include "cdflib_private.h" 

int cdflib_ipmpar(int i)
{
	/* System generated locals */
	int ret_val;

	/* ----------------------------------------------------------------------- */
	/*     INTEGER MACHINE CONSTANTS */

	/*     ASSUME intS ARE REPRESENTED IN THE N-DIGIT, BASE-A FORM */

	/*               SIGN ( X(N-1)*A**(N-1) + ... + X(1)*A + X(0) ) */

	/*               WHERE 0 .LE. X(I) .LT. A FOR I=0,...,N-1. */

	/*     A, THE BASE. */
	/*     N, THE NUMBER OF BASE-A DIGITS. */
	/*     IPMPAR(3) = A**N - 1, THE LARGEST MAGNITUDE. */

	/*  FLOATING-POINT NUMBERS. */

	/*     IT IS ASSUMED THAT THE SINGLE AND DOUBLE PRECISION FLOATING */
	/*     POINT ARITHMETICS HAVE THE SAME BASE, SAY B, AND THAT THE */
	/*     NONZERO NUMBERS ARE REPRESENTED IN THE FORM */

	/*               SIGN (B**E) * (X(1)/B + ... + X(M)/B**M) */

	/*               WHERE X(I) = 0,1,...,B-1 FOR I=1,...,M, */
	/*               X(1) .GE. 1, AND EMIN .LE. E .LE. EMAX. */

	/*     IPMPAR(4) = B, THE BASE. */
	/*  DOUBLE-PRECISION */
	/*     IPMPAR(9) = EMIN, THE SMALLEST EXPONENT E. */
	/*     IPMPAR(10) = EMAX, THE LARGEST EXPONENT E. */
	/* ----------------------------------------------------------------------- */
	/*     UPDATED BY JPC to use lapack dlamch + a small c program */
	/*     for ipmpar(3) */
	/* ----------------------------------------------------------------------- */
	/*      include 'stack.h' */
	switch (i) {
	case 3:  
		{
			// A**N - 1, THE LARGEST MAGNITUDE
			ret_val = cdflib_largestint();
			break;
		}
	case 4:  
		{
			// B, THE BASE
			// ret_val = (int) dlamch_("b", (long int)1);
			ret_val=2;
			break;
		}
	case 9:  
		{
			// EMIN, THE SMALLEST EXPONENT E
			//ret_val = (int) dlamch_("m", (long int)1);
			ret_val = -1021;
			break;
		}
	case 10:  
		{
			// EMAX, THE LARGEST EXPONENT E
			//ret_val = (int) dlamch_("l", (long int)1);
			ret_val = 1024;
			break;
		}
	default:
		{
			cdflib_messageprint ( "cdflib(ipmpar): called with wrong argument" );
			ret_val = 0;
			break;
		}
	}
	return ret_val;
}
